@@ -514,7 +514,7 @@ def parse_args():
   parser.add_argument('--outdir', type=pathlib.Path, required=True)
   parser.add_argument('--subdir', type=boolean, default=True)
   parser.add_argument('--xaxis', type=str, default='step')
-  parser.add_argument('--yaxis', type=str, default='train_return')  # TODO
+  parser.add_argument('--yaxis', type=str, default='eval_return')
   parser.add_argument('--tasks', nargs='+', default=[r'.*'])
   parser.add_argument('--methods', nargs='+', default=[r'.*'])
   parser.add_argument('--baselines', nargs='+', default=DEFAULT_BASELINES)
